16.70. cdist-type__install_partition_msdos_apply(7) — cdist 6.5.4 documentation

# 16.70. cdist-type__install_partition_msdos_apply(7)

## 16.70.1. NAME

cdist-type__install_partition_msdos_apply - Apply dos partition settings

## 16.70.2. DESCRIPTION

Create the partitions defined with __install_partition_msdos

## 16.70.3. REQUIRED PARAMETERS

None

## 16.70.4. OPTIONAL PARAMETERS

None

## 16.70.5. EXAMPLES

    __install_partition_msdos_apply

## 16.70.6. SEE ALSO

cdist-type__install_partition_msdos_apply(7)

## 16.70.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.70.8. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.